==> moodle-2.8.7.zip: moodle/repository/youtube/lang/en/repository_youtube.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'repository_youtube', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   repository_youtube
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['apierror'] = '{$a}';
$string['apikey'] = 'API key';
$string['information'] = 'Get a <a href="https://developers.google.com/youtube/v3/getting-started">Google API key</a> for your Moodle site.';
$string['pluginname'] = 'Youtube videos';
$string['search'] = 'Search videos';
$string['youtube:view'] = 'Use youtube in file picker';
$string['configplugin'] = 'YouTube repository type configuration';
$string['sortby'] = 'Sort By';
$string['sortpublished'] = 'Date Published';
$string['sortrating'] = 'Rating';
$string['sortrelevance'] = 'Relevance';
$string['sortviewcount'] = 'View Count';

==> moodle-3.3.8.zip: moodle/repository/youtube/lang/en/repository_youtube.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'repository_youtube', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   repository_youtube
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['apierror'] = '{$a}';
$string['apikey'] = 'API key';
$string['information'] = 'Get a <a href="https://developers.google.com/youtube/v3/getting-started">Google API key</a> for your Moodle site.';
$string['pluginname'] = 'YouTube videos';
$string['search'] = 'Search videos';
$string['youtube:view'] = 'Use YouTube in file picker';
$string['configplugin'] = 'YouTube repository type configuration';
$string['sortby'] = 'Sort By';
$string['sortpublished'] = 'Date Published';
$string['sortrating'] = 'Rating';
$string['sortrelevance'] = 'Relevance';
$string['sortviewcount'] = 'View Count';
$string['privacy:metadata:repository_youtube'] = 'The YouTube videos repository plugin does not store any personal data, but does transmit user data from Moodle to the remote system.';
$string['privacy:metadata:repository_youtube:searchtext'] = 'The YouTube videos repository user search text query.';
